import os
import sqlite3
import requests

def read_music_database(url):
    conn = sqlite3.connect(requests.get(url).content)
    c = conn.cursor()
    c.execute('SELECT * FROM music')
    music_list = c.fetchall()
    conn.close()
    return music_list

def read_count_database():
    conn = sqlite3.connect('assets/localwrapped/count.db')
    c = conn.cursor()
    c.execute('SELECT * FROM count')
    count_list = c.fetchall()
    conn.close()
    return count_list

def total_play_time(url):
    total_time = 0
    for countvar in read_count_database():
        for musicvar in read_music_database(url):
            if countvar[0] == musicvar[0]:
                total_time += float(musicvar[-1]) * countvar[1]
    return total_time

def generatehtmlcode(url):
    html = '<DOCTYPE html>\n<html>\n'
    html += '<head>\n<meta charset="UTF-8">\n<link href="https://fonts.googleapis.com/css2?family=Jetbrains+Mono:wght@400;700&display=swap" rel="stylesheet">\n</head>\n'
    html += '<body style="background-color: #1f1f1f; color: #ffffff; font-family: \'Jetbrains Mono\', monospace;">\n<meta name="viewport" content="width=device-width, initial-scale=1.0">\n'
    html += '<title>Halhadus\' Local Wrapped</title>\n<link rel="icon" type="image/png" href="assets/favicon.png">\n'
    html += '<meta name="description" content="Halhadus\' Local Wrapped">\n<meta property="og:title" content="Halhadus\' Local Wrapped">\n'
    html += '<meta property="og:description" content="Halhadus\' Local Wrapped">\n<meta property="og:image" content="assets/favicon.png">\n'
    html += '<meta property="og:url" content="https://halhadus.rocks/localwrapped.html">\n'
    html += '<h1>Halhadus\' Local Wrapped</h1>\n'
    html += '<h2>Total Play Time: ' + str(int(total_play_time(url)/60)) + ' minutes</h2>\n'
    html += '<h3>Last Updated: ' + os.path.getmtime('assets/localwrapped/count.db') + '</h3>\n'
    html += '<h3>Most Played Musics</h3>\n'
    html += '<ol>\n'
    count_list_formatted = []
    for music in read_count_database():
        music_name = music[0]
        count = music[1]
        count_list_formatted.append([music_name, count])
    count_list_formatted.sort(key=lambda x: x[1], reverse=True)
    for music in count_list_formatted:
        html += '<li>' + music[0] + ' | ' + str(music[1]) + ' times</li>\n'
    html += '</ol>\n'
    html += '</body>\n</html>'
    return html 
